@@ -79,7 +79,8 @@ def parse_changelog_repo(repo, branch, filename):
 
     return ChangeLog(repo.show(sha))
 
-def orig_file(cp, compression):
+
+def orig_file(cp, compression, subtarball=None):
     """
     The name of the orig file belonging to changelog cp
 
@@ -87,10 +88,14 @@ def orig_file(cp, compression):
     'foo_1.0.orig.tar.bz2'
     >>> orig_file({'Source': 'bar', 'Upstream-Version': '0.0~git1234'}, "xz")
     'bar_0.0~git1234.orig.tar.xz'
+    >>> orig_file({'Source': 'bar', 'Upstream-Version': '0.0~git1234'}, "xz", subtarball="sub1")
+    'bar_0.0~git1234.orig-sub1.tar.xz'
     """
     return DebianPkgPolicy.build_tarball_name(cp['Source'],
                                               cp['Upstream-Version'],
-                                              compression)
+                                              compression,
+                                              subtarball=subtarball)
+
 
 def get_arch():
     pipe = subprocess.Popen(["dpkg", "--print-architecture"], shell=False, stdout=subprocess.PIPE)
