@@ -1,6 +1,7 @@
+
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006-2015 Guido Günther <agx@sigxcpu.org>
+# (C) 2006-2016 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -43,14 +44,15 @@ from gbp.scripts.common.buildpackage import (index_name, wc_name,
                                              write_wc, drop_index)
 from gbp.pkg import compressor_opts, compressor_aliases, parse_archive_filename
 
-def git_archive(repo, cp, output_dir, treeish, comp_type, comp_level, with_submodules):
+#{ upstream tarball preparation
+def git_archive(repo, cp, output_dir, treeish, comp_type, comp_level, with_submodules, subtarball=None):
     "create a compressed orig tarball in output_dir using git_archive"
     try:
         comp_opts = compressor_opts[comp_type][0]
     except KeyError:
         raise GbpError("Unsupported compression type '%s'" % comp_type)
 
-    output = os.path.join(output_dir, du.orig_file(cp, comp_type))
+    output = os.path.join(output_dir, du.orig_file(cp, comp_type, subtarball=subtarball))
     prefix = "%s-%s" % (cp['Source'], cp['Upstream-Version'])
 
     try:
@@ -85,32 +87,44 @@ def prepare_upstream_tarball(repo, cp, options, tarball_dir, output_dir):
                                         options.comp_type,
                                         cp,
                                         options.tarball_dir)
-    orig_file = du.orig_file(cp, options.comp_type)
+
+    orig_files = [du.orig_file(cp, options.comp_type)]
+    if options.subtarballs:
+        orig_files += [du.orig_file(cp, options.comp_type, sub) for sub in options.subtarballs]
 
     # look in tarball_dir first, if found force a symlink to it
     if options.tarball_dir:
-        gbp.log.debug("Looking for orig tarball '%s' at '%s'" % (orig_file, tarball_dir))
-        if not du.DebianPkgPolicy.symlink_orig(orig_file, tarball_dir, output_dir, force=True):
-            gbp.log.info("Orig tarball '%s' not found at '%s'" % (orig_file, tarball_dir))
+        gbp.log.debug("Looking for orig tarballs '%s' at '%s'" % (", ".join(orig_files), tarball_dir))
+        missing = du.DebianPkgPolicy.symlink_origs(orig_files, tarball_dir, output_dir, force=True)
+        if missing:
+            msg = "Tarballs '%s' not found at '%s'" % (", ".join(missing), tarball_dir)
         else:
-            gbp.log.info("Orig tarball '%s' found at '%s'" % (orig_file, tarball_dir))
-    # build an orig unless the user forbids it, always build (and overwrite pre-existing) if user forces it
-    if options.force_create or (not options.no_create_orig and not du.DebianPkgPolicy.has_orig(orig_file, output_dir)):
+            msg = "All Orig tarballs '%s' found at '%s'" % (", ".join(orig_files), tarball_dir)
+        gbp.log.info(msg)
+    if options.no_create_orig:
+        return
+    # Create tarball if missing or forced
+    if not du.DebianPkgPolicy.has_origs(orig_files, output_dir) or options.force_create:
         if not pristine_tar_build_orig(repo, cp, output_dir, options):
             upstream_tree = git_archive_build_orig(repo, cp, output_dir, options)
             if options.pristine_tar_commit:
-                if repo.pristine_tar.has_commit(cp.name,
-                                                cp.upstream_version,
-                                                options.comp_type):
-                    gbp.log.debug("%s already on pristine tar branch" %
-                                  orig_file)
-                else:
-                    archive = os.path.join(output_dir, orig_file)
-                    gbp.log.debug("Adding %s to pristine-tar branch" %
-                                  archive)
-                    repo.pristine_tar.commit(archive, upstream_tree)
+                pristine_tar_commit(repo, cp, options, output_dir, orig_files[0], upstream_tree)
 
 
+def pristine_tar_commit(repo, cp, options, output_dir, orig_file, upstream_tree):
+    if repo.pristine_tar.has_commit(cp.name,
+                                    cp.upstream_version,
+                                    options.comp_type):
+        gbp.log.debug("%s already on pristine tar branch" %
+                      orig_file)
+    else:
+        archive = os.path.join(output_dir, orig_file)
+        gbp.log.debug("Adding %s to pristine-tar branch" %
+                      archive)
+        repo.pristine_tar.commit(archive, upstream_tree)
+
+#}
+
 #{ Functions to handle export-dir
 def write_tree(repo, options):
     """
@@ -226,20 +240,39 @@ def prepare_output_dir(dir):
             raise GbpError("Cannot create output dir %s" % output_dir)
     return output_dir
 
+
 def pristine_tar_build_orig(repo, cp, output_dir, options):
     """
-    build orig using pristine-tar
-    @return: True: orig tarball build, False: noop
+    Build orig tarball using pristine-tar
+
+    @returns: C{True} if tarball was build, C{False} otherwise
     """
     if options.pristine_tar:
         if not repo.has_branch(repo.pristine_tar_branch):
             gbp.log.warn('Pristine-tar branch "%s" not found' %
                          repo.pristine_tar.branch)
+
+        # Make sure the upstream tree exists, it might not be there in
+        # case of subtarballs since we don't keep a ref to it
+        if options.subtarballs:
+            try:
+                upstream_tag = repo.version_to_tag(options.upstream_tag, cp.upstream_version)
+                tree_name = "%s^{tree}" % upstream_tag
+                repo.tree_drop_dirs(tree_name, options.subtarballs)
+            except GitRepositoryError:
+                raise GbpError("Couldn't find upstream tree '%s' to create orig tarball via pristine-tar" % tree_name)
+
         try:
             repo.pristine_tar.checkout(cp.name,
                                        cp.upstream_version,
                                        options.comp_type,
                                        output_dir)
+            for subtarball in options.subtarballs:
+                repo.pristine_tar.checkout(cp.name,
+                                           cp.upstream_version,
+                                           options.comp_type,
+                                           output_dir,
+                                           subtarball=subtarball)
             return True
         except CommandExecFailed:
             if options.pristine_tar_commit:
@@ -271,7 +304,7 @@ def get_upstream_tree(repo, cp, options):
 
 def git_archive_build_orig(repo, cp, output_dir, options):
     """
-    Build orig tarball using git-archive
+    Build orig tarball(s) using git-archive
 
     @param cp: the changelog of the package we're acting on
     @type cp: L{ChangeLog}
@@ -283,16 +316,31 @@ def git_archive_build_orig(repo, cp, output_dir, options):
     @rtype: C{str}
     """
     upstream_tree = get_upstream_tree(repo, cp, options)
-    gbp.log.info("%s does not exist, creating from '%s'" % (du.orig_file(cp,
-                                                            options.comp_type),
-                                                            upstream_tree))
+    gbp.log.info("Creating %s from '%s'" % (du.orig_file(cp,
+                                                         options.comp_type),
+                                            upstream_tree))
     gbp.log.debug("Building upstream tarball with compression '%s -%s'" %
                   (options.comp_type, options.comp_level))
-    if not git_archive(repo, cp, output_dir, upstream_tree,
+    main_tree = repo.tree_drop_dirs(upstream_tree, options.subtarballs)
+    if not git_archive(repo, cp, output_dir, main_tree,
                        options.comp_type,
                        options.comp_level,
                        options.with_submodules):
         raise GbpError("Cannot create upstream tarball at '%s'" % output_dir)
+    for subtarball in options.subtarballs:
+        subtree = repo.tree_get_dir(upstream_tree, subtarball)
+        if not subtree:
+            raise GbpError("No tree for '%s' found in '%s' to create subtarball from" % (subtarball, upstream_tree))
+        gbp.log.info("Creating subtarball '%s' from '%s'" % (du.orig_file(cp,
+                                                                          options.comp_type,
+                                                                          subtarball=subtarball),
+                                                             subtree))
+        if not git_archive(repo, cp, output_dir, subtree,
+                           options.comp_type,
+                           options.comp_level,
+                           options.with_submodules,
+                           subtarball=subtarball):
+            raise GbpError("Cannot create upstream component tarball %s at '%s'" % (subtarball, output_dir))
     return upstream_tree
 
 
@@ -496,6 +544,8 @@ def build_parser(name, prefix=None):
                       help="Compression type, default is '%(compression)s'")
     orig_group.add_config_file_option(option_name="compression-level", dest="comp_level",
                       help="Compression level, default is '%(compression-level)s'")
+    orig_group.add_option("--git-subtarball", action="append", metavar='SUBTARBALL',
+                          dest="subtarballs", help="subtarsball to generate, can be given multiple times", default=[])
     branch_group.add_config_file_option(option_name="upstream-branch", dest="upstream_branch")
     branch_group.add_config_file_option(option_name="debian-branch", dest="debian_branch")
     branch_group.add_boolean_config_file_option(option_name = "ignore-branch", dest="ignore_branch")
@@ -561,6 +611,10 @@ def parse_args(argv, prefix):
         gbp.log.warning("--git-dont-purge is depreceted, use --git-no-purge instead")
         options.purge = False
 
+    if options.subtarballs and options.pristine_tar_commit:
+        gbp.log.warning("Subtarballs specified, pristine-tar-commit not yet supported - disabling it.")
+        options.pristine_tar_commit = False
+
     return options, args, dpkg_args
 
 
