@@ -41,6 +41,19 @@ class SkipImport(Exception):
     pass
 
 
+def generate_pristine_tarballs(repo, src, upstream_tree):
+    subdirs = src.additional_tarballs.keys()
+    main_tree = repo.tree_drop_dirs(upstream_tree, subdirs)
+
+    for dir, tarball in src.additional_tarballs.items():
+        subtree = repo.tree_get_dir(upstream_tree, dir)
+        if not subtree:
+            raise GbpError("No tree for '%s' found in '%s' to create pristine tar commit from" % (dir, upstream_tree))
+        gbp.log.debug("Creating pristine tar commit '%s' from '%s'" % (dir, subtree))
+        repo.pristine_tar.commit(tarball, subtree)
+    repo.pristine_tar.commit(src.tgz, main_tree)
+
+
 def download_source(pkg, dirs, unauth):
     opts = [ '--download-only' ]
     if unauth:
@@ -328,13 +341,11 @@ def main(argv):
 
             if repo.bare:
                 disable_pristine_tar(options, "Bare repository")
-            elif src.additional_tarballs:
-                disable_pristine_tar(options, "Component tarballs found")
 
             dirs['tmp'] = os.path.abspath(tempfile.mkdtemp(dir='..'))
             upstream = DebianUpstreamSource(src.tgz)
             upstream.unpack(dirs['tmp'], options.filters)
-            for tarball in src.additional_tarballs:
+            for tarball in src.additional_tarballs.values():
                 gbp.log.info("Found component tarball '%s'" % os.path.basename(tarball))
                 subtarball = DebianUpstreamSource(tarball)
                 subtarball.unpack(upstream.unpacked, options.filters)
@@ -389,7 +400,7 @@ def main(argv):
                     if is_empty:
                         repo.create_branch(options.upstream_branch, commit)
                     if options.pristine_tar:
-                        repo.pristine_tar.commit(src.tgz, options.upstream_branch)
+                        generate_pristine_tarballs(repo, src, options.upstream_branch)
                 if (not repo.has_branch(options.debian_branch)
                     and (is_empty or options.create_missing_branches)):
                     repo.create_branch(options.debian_branch, commit)
