@@ -66,15 +66,15 @@ class TestGbpBuildpackageDep14(DebianGitTestRepo):
         self.repo.create_branch(branch)
         self.repo.set_branch(branch)
         with self.assertRaisesRegexp(GbpError,
-                                     'DEP14 DIST setup needs branch name to be vendor/suite'):
+                                     "DEP14 DIST: Current branch 'sid' does not match vendor/suite"):
             get_pbuilder_dist(self.options, self.repo)
 
     def test_get_pbuilder_dist_dep14_too_many_slashes(self):
-        branch = 'too/many/slashed'
+        branch = 'too/many/slashes'
         self.repo.create_branch(branch)
         self.repo.set_branch(branch)
         with self.assertRaisesRegexp(GbpError,
-                                     'DEP14 DIST setup needs branch name to be vendor/suite'):
+                                     "DEP14 DIST: Current branch 'too/many/slashes' does not match vendor/suite"):
             get_pbuilder_dist(self.options, self.repo)
 
 
