@@ -19,10 +19,14 @@ def test_author():
     'foo'
     >>> modifier.email
     'bar'
-    >>> modifier.get_author_env()
-    {'GIT_AUTHOR_EMAIL': 'bar', 'GIT_AUTHOR_NAME': 'foo'}
-    >>> modifier.get_committer_env()
-    {'GIT_COMMITTER_NAME': 'foo', 'GIT_COMMITTER_EMAIL': 'bar'}
+    >>> modifier.get_author_env()['GIT_AUTHOR_EMAIL']
+    'bar'
+    >>> modifier.get_author_env()['GIT_AUTHOR_NAME']
+    'foo'
+    >>> modifier.get_committer_env()['GIT_COMMITTER_NAME']
+    'foo'
+    >>> modifier.get_committer_env()['GIT_COMMITTER_EMAIL']
+    'bar'
     >>> modifier._get_env('foo')
     Traceback (most recent call last):
     ...
